# -*- coding: utf-8 -*-
from distutils.core import setup

packages = \
['py_wave_runup']

package_data = \
{'': ['*']}

install_requires = \
['numpy>=1.16,<2.0']

setup_kwargs = {
    'name': 'py-wave-runup',
    'version': '0.1.2',
    'description': 'Empirical wave runup models implemented in Python',
    'long_description': '=================\nPython Wave Runup\n=================\n::\n\n    Empirical wave runup models implemented in Python for coastal engineers and scientists.\n\n.. image:: https://img.shields.io/pypi/v/py-wave-runup.svg\n        :target: https://pypi.python.org/pypi/py-wave-runup\n\n.. image:: https://img.shields.io/travis/com/chrisleaman/py-wave-runup.svg\n        :target: https://travis-ci.com/chrisleaman/py-wave-runup\n\n.. image:: https://readthedocs.org/projects/py-wave-runup/badge/?version=latest\n    :target: https://py-wave-runup.readthedocs.io/en/latest/?badge=latest\n    :alt: Documentation Status\n\n.. image:: https://codecov.io/gh/chrisleaman/py-wave-runup/branch/master/graph/badge.svg\n    :target: https://codecov.io/gh/chrisleaman/py-wave-runup\n\n.. image:: https://img.shields.io/badge/code%20style-black-000000.svg\n    :target: https://github.com/ambv/black\n\n.. image:: https://pyup.io/repos/github/chrisleaman/py-wave-runup/shield.svg\n     :target: https://pyup.io/repos/github/chrisleaman/py-wave-runup/\n     :alt: Updates\n\n\nBackground\n----------\n\nWave runup refers to the final part of a wave\'s journey as it travels from offshore\nonto the beach. It is observable by anyone who goes to the beach and watches the edge\nof the water "runup" and rundown the beach. It is comprised of two components:\n\n    - **setup**: the height of the time averaged superelevation of the mean water level\n      above the Still Water Level (SWL)\n    - **swash**: the height of the time varying fluctuation of the instantaneous water\n      level about the setup elevation\n\nSetup, swash and other components of Total Water Level (TWL) rise are shown in this\nhandy figure below.\n\n.. image:: ./docs/_static/VitousekDoubling2017Fig1.jpg\n..\n\n    | Figure from Vitousek et al. (2017) [#vit17]_\n\nWave runup can contribute a significant portion of the increase in TWL in coastal\nstorms causing erosion and inundation. For example, Stockdon et al. (2006) [#sto06]_\ncollated data from numerous experiments, some of which showed wave runup 2% excedence\nheights in excess of 3 m during some storms.\n\nGiven the impact such a large increase in TWL can have on coastlines, there has been\nmuch research conducted to try improve our understanding of wave runup processes.\nAlthough there are many processes which can influence wave runup (such as nonlinear\nwave transformation, wave reflection, three-dimensional effects, porosity, roughness,\npermeability and groundwater) [#cem06]_, many attempts have been made to derive\nempirical relatinoships based on easily measurable parameters. Typically, empirical\nwave runup models include:\n\n    - **Hs**: significant wave height\n    - **Tp**: peak wave length\n    - **beta**: beach slope\n\nThis python package attempts to consolidate the work done by others in this field and\ncollate the numerous empirical relationships for wave runup which have been published.\n\nInstallation\n------------\n\nInstallation of ``py-wave-runup`` can be done with pip:\n\n.. code:: bash\n\n    pip install py-wave-runup\n\n\nUsage\n-----\n\n.. code:: python\n\n    from py_wave_runup import models\n\n    model_sto06 = models.Stockdon2006(Hs=4, Tp=12, beta=0.1)\n\n    model_sto06.R2     # 2.54\n    model_sto06.setup  # 0.96\n    model_sto06.sinc   # 2.06\n    model_sto06.sig    # 1.65\n\n\nDocumentation\n-------------\nDocumentation is located at  https://py-wave-runup.readthedocs.io.\n\n\nContributing\n------------\n\n1. Fork it (https://github.com/chrisleaman/py-wave-runup/fork)\n2. Create your feature branch (``git checkout -b feature/fooBar``)\n3. Commit your changes (``git commit -am \'Add some fooBar``)\n4. Push to the branch (``git push origin feature/fooBar``)\n5. Create a new Pull Request\n\n\nLicense\n--------\n\nDistributed under the GNU General Public License v3.\n\n\nReferences\n----------\n\n.. [#vit17] Vitousek, Sean, Patrick L. Barnard, Charles H. Fletcher, Neil Frazer,\n       Li Erikson, and Curt D. Storlazzi. "Doubling of Coastal Flooding Frequency\n       within Decades Due to Sea-Level Rise." Scientific Reports 7, no. 1 (May 18,\n       2017): 1399. https://doi.org/10.1038/s41598-017-01362-7.\n.. [#sto06] Stockdon, Hilary F., Robert A. Holman, Peter A. Howd, and Asbury H. Sallenger.\n       "Empirical Parameterization of Setup, Swash, and Runup." Coastal Engineering 53,\n       no. 7 (May 1, 2006): 573-88. https://doi.org/10.1016/j.coastaleng.2005.12.005\n.. [#cem06] United States, Army, and Corps of Engineers. Coastal Engineering Manual.\n       Washington, D.C.: U.S. Army Corps of Engineers, 2006.\n',
    'author': 'Chris Leaman',
    'author_email': None,
    'url': 'https://github.com/chrisleaman/py-wave-runup',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.5,<4.0',
}


setup(**setup_kwargs)
